======
aiogmb
======


.. image:: https://img.shields.io/pypi/v/aiogmb.svg
        :target: https://pypi.python.org/pypi/aiogmb

.. image:: https://img.shields.io/travis/krapoed/aiogmb.svg
        :target: https://travis-ci.org/krapoed/aiogmb

.. image:: https://readthedocs.org/projects/aiogmb/badge/?version=latest
        :target: https://aiogmb.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status


.. image:: https://pyup.io/repos/github/krapoed/aiogmb/shield.svg
     :target: https://pyup.io/repos/github/krapoed/aiogmb/
     :alt: Updates



Async client for google's gmb api


* Free software: MIT license
* Documentation: https://aiogmb.readthedocs.io.


Features
--------

* TODO

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
